@@ -6,7 +6,7 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.h 2151 2006-09-06 20:02:47Z rousseau $
+ * $Id: debuglog.h 5434 2010-12-08 14:13:21Z rousseau $
  */
 
 /**
@@ -16,7 +16,6 @@
  * @note log message is sent to syslog or stderr depending on --foreground
  * command line argument
  *
- * @test
  * @code
  * Log1(priority, "text");
  *  log "text" with priority level priority
@@ -34,11 +33,6 @@
 #ifndef __debuglog_h__
 #define __debuglog_h__
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #ifndef PCSC_API
 #define PCSC_API
 #endif
@@ -68,11 +62,29 @@ enum {
 #define __FUNCTION__ ""
 #endif
 
+#ifdef NO_LOG
+
+#define Log0(priority) do { } while(0)
+#define Log1(priority, fmt) do { } while(0)
+#define Log2(priority, fmt, data) do { } while(0)
+#define Log3(priority, fmt, data1, data2) do { } while(0)
+#define Log4(priority, fmt, data1, data2, data3) do { } while(0)
+#define Log5(priority, fmt, data1, data2, data3, data4) do { } while(0)
+#define Log9(priority, fmt, data1, data2, data3, data4, data5, data6, data7, data8) do { } while(0)
+#define LogXxd(priority, msg, buffer, size) do { } while(0)
+
+#define DebugLogA(a) 
+#define DebugLogB(a, b) 
+#define DebugLogC(a, b,c) 
+
+#else
+
 #define Log0(priority) log_msg(priority, "%s:%d:%s()", __FILE__, __LINE__, __FUNCTION__)
 #define Log1(priority, fmt) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__)
 #define Log2(priority, fmt, data) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__, data)
 #define Log3(priority, fmt, data1, data2) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__, data1, data2)
 #define Log4(priority, fmt, data1, data2, data3) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__, data1, data2, data3)
+#define Log5(priority, fmt, data1, data2, data3, data4) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__, data1, data2, data3, data4)
 #define Log9(priority, fmt, data1, data2, data3, data4, data5, data6, data7, data8) log_msg(priority, "%s:%d:%s() " fmt, __FILE__, __LINE__, __FUNCTION__, data1, data2, data3, data4, data5, data6, data7, data8)
 #define LogXxd(priority, msg, buffer, size) log_xxd(priority, msg, buffer, size)
 
@@ -80,6 +92,8 @@ enum {
 #define DebugLogB(a, b) Log2(PCSC_LOG_INFO, a, b)
 #define DebugLogC(a, b,c) Log3(PCSC_LOG_INFO, a, b, c)
 
+#endif	/* NO_LOG */
+
 PCSC_API void log_msg(const int priority, const char *fmt, ...);
 PCSC_API void log_xxd(const int priority, const char *msg,
 	const unsigned char *buffer, const int size);
@@ -90,9 +104,5 @@ int DebugLogSetCategory(const int);
 void DebugLogCategory(const int, const unsigned char *, const int);
 PCSC_API void DebugLogSetLevel(const int level);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif							/* __debuglog_h__ */
 
