@@ -3,9 +3,10 @@
  *
  * Copyright (C) 1999-2003
  *  David Corcoran <corcoran@linuxnet.com>
+ * Copyright (C) 2002-2009
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.h 2319 2007-01-09 15:27:56Z rousseau $
+ * $Id: winscard.h 5341 2010-10-22 11:36:06Z rousseau $
  */
 
 /**
@@ -28,24 +29,23 @@ extern "C"
 #endif
 
 	PCSC_API LONG SCardEstablishContext(DWORD dwScope,
-		LPCVOID pvReserved1, LPCVOID pvReserved2, LPSCARDCONTEXT phContext);
+		/*@null@*/ LPCVOID pvReserved1, /*@null@*/ LPCVOID pvReserved2,
+		/*@out@*/ LPSCARDCONTEXT phContext);
 
 	PCSC_API LONG SCardReleaseContext(SCARDCONTEXT hContext);
 
 	PCSC_API LONG SCardIsValidContext(SCARDCONTEXT hContext);
 
-	PCSC_API LONG SCardSetTimeout(SCARDCONTEXT hContext, DWORD dwTimeout);
-
 	PCSC_API LONG SCardConnect(SCARDCONTEXT hContext,
 		LPCSTR szReader,
 		DWORD dwShareMode,
 		DWORD dwPreferredProtocols,
-		LPSCARDHANDLE phCard, LPDWORD pdwActiveProtocol);
+		/*@out@*/ LPSCARDHANDLE phCard, /*@out@*/ LPDWORD pdwActiveProtocol);
 
 	PCSC_API LONG SCardReconnect(SCARDHANDLE hCard,
 		DWORD dwShareMode,
 		DWORD dwPreferredProtocols,
-		DWORD dwInitialization, LPDWORD pdwActiveProtocol);
+		DWORD dwInitialization, /*@out@*/ LPDWORD pdwActiveProtocol);
 
 	PCSC_API LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition);
 
@@ -53,39 +53,43 @@ extern "C"
 
 	PCSC_API LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition);
 
-	PCSC_API LONG SCardCancelTransaction(SCARDHANDLE hCard);
-
 	PCSC_API LONG SCardStatus(SCARDHANDLE hCard,
-		LPSTR mszReaderNames, LPDWORD pcchReaderLen,
-		LPDWORD pdwState,
-		LPDWORD pdwProtocol,
-		LPBYTE pbAtr, LPDWORD pcbAtrLen);
+		/*@null@*/ /*@out@*/ LPSTR mszReaderName,
+		/*@null@*/ /*@out@*/ LPDWORD pcchReaderLen,
+		/*@null@*/ /*@out@*/ LPDWORD pdwState,
+		/*@null@*/ /*@out@*/ LPDWORD pdwProtocol,
+		/*@null@*/ /*@out@*/ LPBYTE pbAtr,
+		/*@null@*/ /*@out@*/ LPDWORD pcbAtrLen);
 
 	PCSC_API LONG SCardGetStatusChange(SCARDCONTEXT hContext,
 		DWORD dwTimeout,
-		LPSCARD_READERSTATE_A rgReaderStates, DWORD cReaders);
+		LPSCARD_READERSTATE rgReaderStates, DWORD cReaders);
 
 	PCSC_API LONG SCardControl(SCARDHANDLE hCard, DWORD dwControlCode,
 		LPCVOID pbSendBuffer, DWORD cbSendLength,
-		LPVOID pbRecvBuffer, DWORD cbRecvLength, LPDWORD lpBytesReturned);
+		/*@out@*/ LPVOID pbRecvBuffer, DWORD cbRecvLength,
+		LPDWORD lpBytesReturned);
 
 	PCSC_API LONG SCardTransmit(SCARDHANDLE hCard,
-		LPCSCARD_IO_REQUEST pioSendPci,
+		const SCARD_IO_REQUEST *pioSendPci,
 		LPCBYTE pbSendBuffer, DWORD cbSendLength,
-		LPSCARD_IO_REQUEST pioRecvPci,
-		LPBYTE pbRecvBuffer, LPDWORD pcbRecvLength);
+		/*@out@*/ SCARD_IO_REQUEST *pioRecvPci,
+		/*@out@*/ LPBYTE pbRecvBuffer, LPDWORD pcbRecvLength);
 
 	PCSC_API LONG SCardListReaderGroups(SCARDCONTEXT hContext,
-		LPSTR mszGroups, LPDWORD pcchGroups);
+		/*@out@*/ LPSTR mszGroups, LPDWORD pcchGroups);
 
 	PCSC_API LONG SCardListReaders(SCARDCONTEXT hContext,
-		LPCSTR mszGroups,
-		LPSTR mszReaders, LPDWORD pcchReaders);
+		/*@null@*/ /*@out@*/ LPCSTR mszGroups,
+		/*@null@*/ /*@out@*/ LPSTR mszReaders,
+		/*@out@*/ LPDWORD pcchReaders);
+
+	PCSC_API LONG SCardFreeMemory(SCARDCONTEXT hContext, LPCVOID pvMem);
 
 	PCSC_API LONG SCardCancel(SCARDCONTEXT hContext);
 
 	PCSC_API LONG SCardGetAttrib(SCARDHANDLE hCard, DWORD dwAttrId,
-		LPBYTE pbAttr, LPDWORD pcbAttrLen);
+		/*@out@*/ LPBYTE pbAttr, LPDWORD pcbAttrLen);
 
 	PCSC_API LONG SCardSetAttrib(SCARDHANDLE hCard, DWORD dwAttrId,
 		LPCBYTE pbAttr, DWORD cbAttrLen);
