@@ -3,8 +3,10 @@
  *
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
+ * Copyright (C) 2002-2009
+ *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: wintypes.h 2814 2008-02-14 10:49:57Z rousseau $
+ * $Id: wintypes.h 5505 2011-01-14 08:23:58Z rousseau $
  */
 
 /**
@@ -20,7 +22,36 @@ extern "C"
 {
 #endif
 
-#if !defined(WIN32)
+#ifdef __APPLE__
+
+#include <stdint.h>
+
+#ifndef BYTE
+    typedef uint8_t BYTE;
+#endif
+    typedef uint8_t UCHAR;
+    typedef uint8_t *PUCHAR;
+    typedef uint16_t USHORT;
+
+#ifndef __COREFOUNDATION_CFPLUGINCOM__
+    typedef uint32_t ULONG;
+    typedef void *LPVOID;
+    typedef int16_t BOOL;
+#endif
+
+    typedef uint32_t *PULONG;
+    typedef const void *LPCVOID;
+    typedef uint32_t DWORD;
+    typedef uint32_t *PDWORD;
+    typedef uint16_t WORD;
+    typedef int32_t LONG;
+    typedef const char *LPCSTR;
+    typedef const BYTE *LPCBYTE;
+    typedef BYTE *LPBYTE;
+    typedef DWORD *LPDWORD;
+    typedef char *LPSTR;
+
+#else
 
 #ifndef BYTE
 	typedef unsigned char BYTE;
@@ -54,8 +85,6 @@ extern "C"
 	typedef unsigned short WORD;
 	typedef unsigned long *PULONG;
 
-#else
-#include <windows.h>
 #endif
 
 #ifdef __cplusplus
