@@ -3,10 +3,10 @@
  *
  * Copyright (C) 1999-2002
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 1999-2008
+ * Copyright (C) 2002-2009
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 1953 2006-03-21 13:46:28Z rousseau $
+ * $Id: debug.c 5196 2010-08-27 12:52:27Z rousseau $
  */
 
 /**
@@ -19,12 +19,32 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <stdio.h>
 
-#include "debug.h"
+#include "debuglog.h"
 #include "strlcpycat.h"
 
 #define DEBUG_BUF_SIZE 2048
 
+#ifdef NO_LOG
+
+void log_msg(const int priority, const char *fmt, ...)
+{
+	(void)priority;
+	(void)fmt;
+}
+
+void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
+	const int len)
+{
+	(void)priority;
+	(void)msg;
+	(void)buffer;
+	(void)len;
+}
+
+#else
+
 /** default level is quiet to avoid polluting fd 2 (possibly NOT stderr) */
 static char LogLevel = PCSC_LOG_CRITICAL+1;
 
@@ -142,3 +162,5 @@ void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
 	fprintf(stderr, "%s\n", DebugBuffer);
 } /* log_xxd */
 
+#endif
+
