@@ -3,10 +3,10 @@
  *
  * Copyright (C) 1999-2002
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 1999-2005
+ * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 4241 2009-06-02 13:50:52Z rousseau $
+ * $Id: debuglog.c 5047 2010-06-29 14:39:24Z rousseau $
  */
 
 /**
@@ -34,6 +34,55 @@
 #include "sys_generic.h"
 #include "strlcpycat.h"
 
+#ifdef NO_LOG
+
+void log_msg(const int priority, const char *fmt, ...)
+{
+	(void)priority;
+	(void)fmt;
+}
+
+void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
+	const int len)
+{
+	(void)priority;
+	(void)msg;
+	(void)buffer;
+	(void)len;
+}
+
+void DebugLogSuppress(const int lSType)
+{
+	(void)lSType;
+}
+
+void DebugLogSetLogType(const int dbgtype)
+{
+	(void)dbgtype;
+}
+
+void DebugLogSetLevel(const int level)
+{
+	(void)level;
+}
+
+INTERNAL int DebugLogSetCategory(const int dbginfo)
+{
+	(void)dbginfo;
+
+	return 0;
+}
+
+INTERNAL void DebugLogCategory(const int category, const unsigned char *buffer,
+	const int len)
+{
+	(void)category;
+	(void)buffer;
+	(void)len;
+}
+
+#else
+
 /**
  * Max string size when dumping a 256 bytes longs APDU
  * Should be bigger than 256*3+30
@@ -165,12 +214,10 @@ void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
 	log_xxd_always(priority, msg, buffer, len);
 } /* log_xxd */
 
-#ifdef PCSCD
 void DebugLogSuppress(const int lSType)
 {
 	LogSuppress = lSType;
 }
-#endif
 
 void DebugLogSetLogType(const int dbgtype)
 {
@@ -305,3 +352,5 @@ void debug_xxd(const char *msg, const unsigned char *buffer, const int len)
 } /* debug_xxd */
 #endif
 
+#endif	/* NO_LOG */
+
