@@ -3,8 +3,10 @@
  *
  * Copyright (C) 2000-2003
  *  David Corcoran <corcoran@linuxnet.com>
+ * Copyright (C) 2002-2010
+ *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: hotplug_generic.c 2748 2008-01-21 09:10:58Z rousseau $
+ * $Id: hotplug_generic.c 5638 2011-02-25 13:36:57Z rousseau $
  */
 
 /**
@@ -25,9 +27,7 @@
 #define FALSE 0
 #endif
 
-#if !defined(__APPLE__) && !defined(HAVE_LIBUSB) && !defined(__linux__) && !defined(HAVE_LIBHAL)
-
-char ReCheckSerialReaders = FALSE;
+#if !defined(__APPLE__) && !defined(HAVE_LIBUSB) && !defined(__linux__) && !defined(HAVE_LIBUDEV)
 
 LONG HPSearchHotPluggables(void)
 {
@@ -46,7 +46,6 @@ LONG HPStopHotPluggables(void)
 
 void HPReCheckSerialReaders(void)
 {
-	ReCheckSerialReaders = TRUE;
 }
 
 #endif
