@@ -3,10 +3,12 @@
  *
  * Copyright (C) 2001-2004
  *  David Corcoran <corcoran@linuxnet.com>
+ * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
+ * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.h 4321 2009-07-17 14:21:50Z rousseau $
+ * $Id: winscard_msg.h 5434 2010-12-08 14:13:21Z rousseau $
  */
 
 /**
@@ -21,14 +23,9 @@
 #include <stdint.h>
 
 /** Major version of the current message protocol */
-#define PROTOCOL_VERSION_MAJOR 3
+#define PROTOCOL_VERSION_MAJOR 4
 /** Minor version of the current message protocol */
-#define PROTOCOL_VERSION_MINOR 0
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif
+#define PROTOCOL_VERSION_MINOR 2
 
 	/**
 	 * @brief Information transmitted in \ref CMD_VERSION Messages.
@@ -39,48 +36,14 @@ extern "C"
 		int32_t minor;	/**< IPC minor \ref PROTOCOL_VERSION_MINOR */
 		uint32_t rv;
 	};
-	typedef struct version_struct version_struct;
 
 	/**
-	 * @brief General structure for client/serve message data exchange.
-	 *
-	 * It is used in the calls of \c SHMMessageSend and \c SHMMessageReceive.
-	 * The field \c data is interpreted according to the values of the fields
-	 * \c mtype and \c command. The possible structs the \c data field can
-	 * represent are: \c version_struct \c client_struct \c establish_struct
-	 * \c release_struct \c connect_struct \c reconnect_struct
-	 * \c disconnect_struct \c begin_struct \c end_struct \c cancel_struct
-	 * \c status_struct \c transmit_struct \c control_struct \c getset_struct
+	 * @brief header structure for client/server message data exchange.
 	 */
-	typedef struct rxSharedSegment
+	struct rxHeader
 	{
-		uint32_t mtype;		/** one of the \c pcsc_adm_commands */
-		uint32_t user_id;
-		uint32_t group_id;
-		uint32_t command;	/** one of the \c pcsc_msg_commands */
-		uint64_t date;
-		unsigned char key[PCSCLITE_MSG_KEY_LEN]; /* 16 bytes */
-		union
-		{
-			unsigned char data[PCSCLITE_MAX_MESSAGE_SIZE];
-			struct version_struct veStr;
-		};
-	}
-	sharedSegmentMsg, *psharedSegmentMsg;
-
-	/**
-	 * Command types available to use in the field \c sharedSegmentMsg.mtype.
-	 */
-	enum pcsc_adm_commands
-	{
-		CMD_FUNCTION = 0xF1,
-		CMD_FAILED = 0xF2,
-		CMD_SERVER_DIED = 0xF3,
-		CMD_CLIENT_DIED = 0xF4,
-		CMD_READER_EVENT = 0xF5,
-		CMD_SYN = 0xF6,
-		CMD_ACK = 0xF7,
-		CMD_VERSION = 0xF8	/**< version of the IPC */
+		uint32_t size;		/**< size of the message excluding this header */
+		uint32_t command;	/**< one of the \c pcsc_msg_commands */
 	};
 
 	/**
@@ -88,6 +51,7 @@ extern "C"
 	 */
 	enum pcsc_msg_commands
 	{
+		CMD_ENUM_FIRST,
 		SCARD_ESTABLISH_CONTEXT = 0x01,	/**< used by SCardEstablishContext() */
 		SCARD_RELEASE_CONTEXT = 0x02,	/**< used by SCardReleaseContext() */
 		SCARD_LIST_READERS = 0x03,		/**< used by SCardListReaders() */
@@ -99,20 +63,31 @@ extern "C"
 		SCARD_TRANSMIT = 0x09,			/**< used by SCardTransmit() */
 		SCARD_CONTROL = 0x0A,			/**< used by SCardControl() */
 		SCARD_STATUS = 0x0B,			/**< used by SCardStatus() */
-		SCARD_GET_STATUS_CHANGE = 0x0C,	/**< used by SCardGetStatusChange() */
+		SCARD_GET_STATUS_CHANGE = 0x0C,	/**< not used */
 		SCARD_CANCEL = 0x0D,			/**< used by SCardCancel() */
-		SCARD_CANCEL_TRANSACTION = 0x0E,
+		SCARD_CANCEL_TRANSACTION = 0x0E,/**< not used */
 		SCARD_GET_ATTRIB = 0x0F,		/**< used by SCardGetAttrib() */
 		SCARD_SET_ATTRIB = 0x10,		/**< used by SCardSetAttrib() */
-		SCARD_TRANSMIT_EXTENDED = 0x11,	/**< used by SCardTransmit() */
-		SCARD_CONTROL_EXTENDED = 0x12	/**< used by SCardControl() */
+		CMD_VERSION = 0x11,				/**< get the client/server protocol version */
+		CMD_GET_READERS_STATE = 0x12,	/**< get the readers state */
+		CMD_WAIT_READER_STATE_CHANGE = 0x13,	/**< wait for a reader state change */
+		CMD_STOP_WAITING_READER_STATE_CHANGE = 0x14,	/**< stop waiting for a reader state change */
+		CMD_ENUM_LAST
 	};
 
 	struct client_struct
 	{
 		uint32_t hContext;
 	};
-	typedef struct client_struct client_struct;
+
+	/**
+	 * @brief Information contained in \ref CMD_WAIT_READER_STATE_CHANGE Messages.
+	 */
+	struct wait_reader_state_change
+	{
+		uint32_t timeOut;	/**< timeout in ms */
+		uint32_t rv;
+	};
 
 	/**
 	 * @brief Information contained in \ref SCARD_ESTABLISH_CONTEXT Messages.
@@ -125,7 +100,6 @@ extern "C"
 		uint32_t hContext;
 		uint32_t rv;
 	};
-	typedef struct establish_struct establish_struct;
 
 	/**
 	 * @brief Information contained in \ref SCARD_RELEASE_CONTEXT Messages.
@@ -137,7 +111,6 @@ extern "C"
 		uint32_t hContext;
 		uint32_t rv;
 	};
-	typedef struct release_struct release_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_CONNECT Messages.
@@ -154,7 +127,6 @@ extern "C"
 		uint32_t dwActiveProtocol;
 		uint32_t rv;
 	};
-	typedef struct connect_struct connect_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_RECONNECT Messages.
@@ -170,7 +142,6 @@ extern "C"
 		uint32_t dwActiveProtocol;
 		uint32_t rv;
 	};
-	typedef struct reconnect_struct reconnect_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_DISCONNECT Messages.
@@ -183,7 +154,6 @@ extern "C"
 		uint32_t dwDisposition;
 		uint32_t rv;
 	};
-	typedef struct disconnect_struct disconnect_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_BEGIN_TRANSACTION Messages.
@@ -195,7 +165,6 @@ extern "C"
 		int32_t hCard;
 		uint32_t rv;
 	};
-	typedef struct begin_struct begin_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_END_TRANSACTION Messages.
@@ -208,7 +177,6 @@ extern "C"
 		uint32_t dwDisposition;
 		uint32_t rv;
 	};
-	typedef struct end_struct end_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_CANCEL Messages.
@@ -217,10 +185,9 @@ extern "C"
 	 */
 	struct cancel_struct
 	{
-		int32_t hCard;
+		int32_t hContext;
 		uint32_t rv;
 	};
-	typedef struct cancel_struct cancel_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_STATUS Messages.
@@ -230,15 +197,8 @@ extern "C"
 	struct status_struct
 	{
 		int32_t hCard;
-		char mszReaderNames[MAX_READERNAME];
-		uint32_t pcchReaderLen;
-		uint32_t dwState;
-		uint32_t dwProtocol;
-		uint8_t pbAtr[MAX_ATR_SIZE];
-		uint32_t pcbAtrLen;
 		uint32_t rv;
 	};
-	typedef struct status_struct status_struct;
 
 	/**
 	 * @brief contained in \ref SCARD_TRANSMIT Messages.
@@ -246,26 +206,6 @@ extern "C"
 	 * These data are passed throw the field \c sharedSegmentMsg.data.
 	 */
 	struct transmit_struct
-	{
-		int32_t hCard;
-		uint32_t ioSendPciProtocol;
-		uint32_t ioSendPciLength;
-		uint8_t pbSendBuffer[MAX_BUFFER_SIZE];
-		uint32_t cbSendLength;
-		uint32_t ioRecvPciProtocol;
-		uint32_t ioRecvPciLength;
-		uint8_t pbRecvBuffer[MAX_BUFFER_SIZE];
-		uint32_t pcbRecvLength;
-		uint32_t rv;
-	};
-	typedef struct transmit_struct transmit_struct;
-
-	/**
-	 * @brief contained in \ref SCARD_TRANSMIT_EXTENDED Messages.
-	 *
-	 * These data are passed throw the field \c sharedSegmentMsg.data.
-	 */
-	struct transmit_struct_extended
 	{
 		int32_t hCard;
 		uint32_t ioSendPciProtocol;
@@ -275,10 +215,7 @@ extern "C"
 		uint32_t ioRecvPciLength;
 		uint32_t pcbRecvLength;
 		uint32_t rv;
-		uint64_t size;
-		uint8_t data[1];
 	};
-	typedef struct transmit_struct_extended transmit_struct_extended;
 
 	/**
 	 * @brief contained in \ref SCARD_CONTROL Messages.
@@ -286,24 +223,6 @@ extern "C"
 	 * These data are passed throw the field \c sharedSegmentMsg.data.
 	 */
 	struct control_struct
-	{
-		int32_t hCard;
-		uint32_t dwControlCode;
-		uint8_t pbSendBuffer[MAX_BUFFER_SIZE];
-		uint32_t cbSendLength;
-		uint8_t pbRecvBuffer[MAX_BUFFER_SIZE];
-		uint32_t cbRecvLength;
-		uint32_t dwBytesReturned;
-		uint32_t rv;
-	};
-	typedef struct control_struct control_struct;
-
-	/**
-	 * @brief contained in \ref SCARD_CONTROL_EXTENDED Messages.
-	 *
-	 * These data are passed throw the field \c sharedSegmentMsg.data.
-	 */
-	struct control_struct_extended
 	{
 		int32_t hCard;
 		uint32_t dwControlCode;
@@ -311,10 +230,7 @@ extern "C"
 		uint32_t cbRecvLength;
 		uint32_t dwBytesReturned;
 		uint32_t rv;
-		uint64_t size;
-		uint8_t data[1];
 	};
-	typedef struct control_struct_extended control_struct_extended;
 
 	/**
 	 * @brief contained in \ref SCARD_GET_ATTRIB and \c  Messages.
@@ -329,28 +245,25 @@ extern "C"
 		uint32_t cbAttrLen;
 		uint32_t rv;
 	};
-	typedef struct getset_struct getset_struct;
 
 	/*
 	 * Now some function definitions
 	 */
 
-	int32_t SHMClientRead(psharedSegmentMsg, uint32_t, int32_t);
-	int32_t SHMClientSetupSession(uint32_t *);
-	int32_t SHMClientCloseSession(uint32_t);
-	int32_t SHMInitializeCommonSegment(void);
-	int32_t SHMProcessEventsContext(uint32_t, /*@out@*/ psharedSegmentMsg);
-	int32_t SHMProcessEventsServer(/*@out@*/ uint32_t *);
-	int32_t SHMMessageSend(void *buffer, uint64_t buffer_size, int32_t filedes,
-		int32_t blockAmount);
-	int32_t SHMMessageReceive(/*@out@*/ void *buffer, uint64_t buffer_size,
-		int32_t filedes, int32_t blockAmount);
-	int32_t WrapSHMWrite(uint32_t command, uint32_t dwClientID, uint64_t size,
-		uint32_t blockAmount, void *data);
-	void SHMCleanupSharedSegment(int32_t, const char *);
-
-#ifdef __cplusplus
-}
+#ifdef PCSCD
+	int32_t InitializeSocket(void);
+	int32_t ProcessEventsServer(/*@out@*/ uint32_t *);
+#else
+	char *getSocketName(void);
+	int32_t ClientSetupSession(uint32_t *);
+	int32_t ClientCloseSession(uint32_t);
+	LONG MessageReceiveTimeout(uint32_t command, /*@out@*/ void *buffer,
+		uint64_t buffer_size, int32_t filedes, int32_t timeOut);
+	LONG MessageSendWithHeader(uint32_t command, uint32_t dwClientID,
+		uint64_t size, void *data);
 #endif
+	LONG MessageSend(void *buffer, uint64_t buffer_size, int32_t filedes);
+	LONG MessageReceive(/*@out@*/ void *buffer, uint64_t buffer_size,
+		int32_t filedes);
 
 #endif
